@@ -80,7 +80,7 @@ class SpiderController(Thread):
                 self.waiting = False
                 self.parse_task(task=task)
             except DropRequestException as e:
-                logger.warning(f"丢弃请求：{e.args}")
+                logger.warning(f"丢弃请求：{e}")
             except Exception as e:
                 if settings.SPIDER_STOP_ON_ERROR:
                     raise
@@ -128,8 +128,9 @@ class SpiderController(Thread):
         if not new_request.url.startswith('http') and response:
             new_request.url = response.urljoin(new_request.url)
 
-        # 添加请求必须参数
-        new_request.cookie_jar = old_request.cookie_jar  # 续上上一个的 cookie_jar
+        # 添加请求必须参数：新 cookieJar 会覆盖老 cookieJar
+        if not new_request.cookie_jar:
+            new_request.cookie_jar = old_request.cookie_jar  # 续上上一个的 cookie_jar
 
         # 修改优先级，深层的函数应该优先处理，避免积压不前（深度爬取）
         if settings.REQUEST_QUEUE_MODE == 3:
